@@ -1,4 +1,6 @@
 test_that("can round trip all types", {
+  skip_if_not_installed("qs")
+  skip_if_not_installed("arrow")
   board <- board_temp()
 
   # Data frames
